/****************************************************************
* Projectname:        Communication DLL for Fischertechnik-Interface
* Moduldescription:   Header-File
*----------------------------------------------------------------
* Internal functions:
* External functions:
*
* Modulname:          interface.h
* Targettyp:          DLL
* Ident:              16.05.2000
* Company:            Maier Software & Hardware
* Adress:             Nieder-Wllstdter Strae 16, 61194 Niddatal, Germany
* Phone:              (0049 60 34) 92 186
* E-Mail:             Dirk.Maier.MSH@t-online.de
* Author:             Dirk Maier
* Modification:       16.05.2000
*                     26.06.2000   UINT (32 Bit) -> WORD (8 Bit)
*                                  UCHAR (8 Bit) -> BYTE (8 Bit)
*
****************************************************************/

#ifndef INTERFACE_H
#define INTERFACE_H

/****************************************************************/
// DLL-Definitions

#ifdef __cplusplus
#define EXPORT extern "C" __declspec(dllexport)
#else
#define EXPORT __declspec(dllexport)
#endif

/****************************************************************/
// Definition

#define INTERFACE_COM1  1
#define INTERFACE_COM2  2
#define INTERFACE_COM3  3
#define INTERFACE_COM4  4

#define INTERFACE_1     1
#define INTERFACE_2     2

#define INTERFACE_OUT1   1
#define INTERFACE_OUT2   2
#define INTERFACE_OUT3   3
#define INTERFACE_OUT4   4
#define INTERFACE_OUT5   5
#define INTERFACE_OUT6   6
#define INTERFACE_OUT7   7
#define INTERFACE_OUT8   8

#define INTERFACE_DIN1   1
#define INTERFACE_DIN2   2
#define INTERFACE_DIN3   3
#define INTERFACE_DIN4   4
#define INTERFACE_DIN5   5
#define INTERFACE_DIN6   6
#define INTERFACE_DIN7   7
#define INTERFACE_DIN8   8
#define INTERFACE_DIN9   9
#define INTERFACE_DIN10  10
#define INTERFACE_DIN11  11
#define INTERFACE_DIN12  12
#define INTERFACE_DIN13  13
#define INTERFACE_DIN14  14
#define INTERFACE_DIN15  15
#define INTERFACE_DIN16  16

#define INTERFACE_AXIN   1
#define INTERFACE_AYIN   2

#define ICOMMAND_STOP       0    // Alle Motoren anhalten
#define ICOMMAND_DIN      193    // read all digital inputs
#define ICOMMAND_DIN_AXIN 197    // read all digital inputs and analog input AX
#define ICOMMAND_DIN_AYIN 201    // read all digital inputs and analog input AY

#define MOTOR_AUS     0
#define MOTOR_RECHTS  1
#define MOTOR_LINKS   2

#define MOTOR_OFF     0
#define MOTOR_RIGHT   1
#define MOTOR_LEFT    2

/****************************************************************/
// Typdefinitionen

typedef struct
  {
    HWND      hWnd;                // Fenster-handle des aufrufenden Fensters
    HANDLE    hComport;            // Handle des zugehrigen COM-Ports
    WORD      uiComport;           // Nummer des zugehrigen COM-Ports 1-4
    WORD      uiInterface;         // Anzahl der Interface an der Schnittstelle 1-2
    BYTE      ucRecallCommand;     // Kommando was whrend Recall an Interface gesendet wird
    BYTE      ucRecallAktiv;       // 1 = Recall-Prozedur (Wiederholungs abfrage) des Interaface aktiv
    BYTE      ucMotor [8];         // Motorausgnge beider Interface
    BYTE      ucInput [16];        // Digitale Eingnge beider Interface
    WORD      uiInputAsBit;        // Digitalen Eingnge b. I. als einzelne Bit in einem Wort
    WORD      uiAnalog_In [2];     // Analoge Eingnge des Masterinterface
    DWORD     dwCount[16];         // Summe der Impulse, die seit dem ersten Aufruf aufgetreten sind
    DWORD     dwFrequenz[16];      // Signal-Frequenz [Hz] des jeweiligen Eingngs
    DWORD     dwPeriode[16];       // Signal-Periodendauer [ms] des jeweiligen Eingangs
    DWORD     dwMesszeit[16];      // Dauer der Messzeit [ms] des jeweiligen Eingangs

  } FI_INTERFACE;

typedef FI_INTERFACE *PFI_INTERFACE;


/****************************************************************/
// Funktionen der DLL

EXPORT HANDLE CALLBACK InitInterfaceDriver (HWND hWnd, WORD uiCOMPort,
                                            WORD uiAnzInterface, PFI_INTERFACE pFi_Interface);
EXPORT BOOL   CALLBACK CloseInterfaceDriver (PFI_INTERFACE pFi_Interface);
EXPORT BOOL   CALLBACK ParameterWahl (HWND hWnd, WORD *puiComPort, WORD *puiInterAnz);
EXPORT BOOL   CALLBACK CallInterface (BYTE ucCommand, PFI_INTERFACE pFi_Interface);
EXPORT int    CALLBACK SetOutput (WORD uiOutput, BYTE ucWert, PFI_INTERFACE pFi_Interface);
EXPORT int    CALLBACK GetDigitalInput (WORD uiDInput, PFI_INTERFACE pFi_Interface);
EXPORT int    CALLBACK GetAnalogInput (WORD uiAInput, PFI_INTERFACE pFi_Interface);
EXPORT HANDLE CALLBACK StartRecallInterface (BYTE ucRecallCommand, PFI_INTERFACE pFi_Interface);
EXPORT int    CALLBACK EndRecallInterface (PFI_INTERFACE pFi_Interface);
EXPORT BOOL   CALLBACK InterfaceDiagnoseStart (HWND hWnd, WORD puiComPort, WORD puiInterAnz);

/****************************************************************/
#endif  // INTERFACE_H
